@@ -5,8 +5,6 @@ use Moose::Role;
 
 use namespace::clean -except => 'meta';
 
-# informative role
-
 __PACKAGE__
 
 __END__
@@ -30,9 +28,10 @@ backends.
 =head1 DESCRIPTION
 
 This backend is an informational role for backends which can store arbitrary
-binary strings.
+binary strings, especially utf8 data as bytes (without reinterpreting it as
+unicode strings when inflating).
 
-This mostly has to do with L<KiokuDB::Backend::Serialize> variants (e.g.
-L<Storable> based serialization is binary safe, while
-L<KiokuDB::Backend::Serialize::JSPON> is not).
+This mostly has to do with L<KiokuDB::Backend::Serialize> variants (for example
+L<KiokuDB::Backend::Serialize::Storable> is binary safe, while
+L<KiokuDB::Backend::Serialize::JSON> is not).
 
